@@ -1,5 +1,5 @@
-/* This file is part of the KDE project
-   Copyright (C) 2005-2006,2008 Tom Albers <tomalbers@kde.nl>
+/*
+   Copyright (C) 2005-2006,2008-2009 Tom Albers <toma@kde.org>
    Copyright (C) 2005-2006 Bram Schoenmakers <bramschoenmakers@kde.nl>
 
    The parts for idle detection is based on
@@ -66,8 +66,6 @@ RSITimer::~RSITimer()
 
 void RSITimer::run()
 {
-    kDebug() << "Starting timer constructor";
-
     startTimer( 1000 );
     slotReadConfig( /* restart */ true );
 
@@ -105,7 +103,9 @@ void RSITimer::checkScreensaverMode()
     XGetScreenSaver( QX11Info::display(), &mXTimeout, &mXInterval, &mXBlanking, &mXExposures );
     static int originalTimeout = mXTimeout;
 
-    kDebug() << "Screensaver timeout is set at " << mXTimeout;
+    if ( m_explicitDebug ) {
+        kDebug() << "Screensaver timeout is set at " << mXTimeout;
+    }
 
     // if the user has no screensaver installed, get out.
     if ( originalTimeout == 0 )
@@ -209,29 +209,15 @@ void RSITimer::resetAfterBigBreak()
 
 // -------------------------- SLOTS ------------------------//
 
-void RSITimer::slotStartNoImage()
+void RSITimer::slotStart()
 {
-    slotStart( false );
-}
-
-
-void RSITimer::slotStart( bool newImage )
-{
-    emit minimize( newImage );
     emit updateIdleAvg( 0.0 );
     m_suspended = false;
 }
 
-void RSITimer::slotStopNoImage()
-{
-    slotStop( false );
-}
-
-void RSITimer::slotStop( bool newImage )
+void RSITimer::slotStop()
 {
     m_suspended = true;
-
-    emit minimize( newImage );
     emit updateIdleAvg( 0.0 );
     emit updateToolTip( 0, 0 );
 }
@@ -246,12 +232,13 @@ void RSITimer::slotRestart()
     m_tiny_left = m_intervals["tiny_minimized"];
     m_big_left = m_intervals["big_minimized"];
     resetAfterBreak();
-    slotStart( false );
+    slotStart();
     m_needRestart = false;
 }
 
 void RSITimer::skipBreak()
 {
+    emit minimize();
     if ( m_big_left <= m_tiny_left ) {
         resetAfterBigBreak();
         RSIGlobals::instance()->stats()->increaseStat( BIG_BREAKS_SKIPPED );
@@ -360,7 +347,7 @@ void RSITimer::timerEvent( QTimerEvent * )
             --m_pause_left;
             updateWidget( m_pause_left );
         } else { // user survived the break, set him/her free
-            emit minimize( true );
+            emit minimize();
 
             // make sure we clean up stuff in the code ahead
             if ( m_nextBreak == TINY_BREAK )
@@ -374,11 +361,12 @@ void RSITimer::timerEvent( QTimerEvent * )
         return;
     }
 
-    //if (m_explicitDebug)
-    kDebug() << " patience: " << m_patience  << " pause_left: "
-    << m_pause_left << " relax_left: " << m_relax_left
-    <<  " tiny_left: " << m_tiny_left  << " big_left: "
-    <<  m_big_left << " idle: " << t << endl;
+    if ( m_explicitDebug ) {
+        kDebug() << " patience: " << m_patience  << " pause_left: "
+        << m_pause_left << " relax_left: " << m_relax_left
+        <<  " tiny_left: " << m_tiny_left  << " big_left: "
+        <<  m_big_left << " idle: " << t << endl;
+    }
 
     if ( t == 0 ) { // activity!
         if ( m_patience > 0 ) { // we're trying to break
@@ -406,14 +394,6 @@ void RSITimer::timerEvent( QTimerEvent * )
         } else if ( m_pause_left == 0 ) {
             // there's no relax moment or break going on.
 
-            // If we emitted tiny/bigBreakSkipped then we have
-            // to emit a signal again when user becomes active.
-            // so if the timers are original, emit it.
-            if ( m_tiny_left == m_intervals["tiny_minimized"] ||
-                    m_big_left == m_intervals["big_minimized"] ) {
-                emit skipBreakEnded();
-            }
-
             --m_tiny_left;
             --m_big_left;
 
@@ -431,7 +411,11 @@ void RSITimer::timerEvent( QTimerEvent * )
         double value = 100 - (( m_tiny_left / ( double )m_intervals["tiny_minimized"] ) * 100 );
         emit updateIdleAvg( value );
     } else if ( m_useIdleDetection && t == m_intervals["big_maximized"] &&
-                m_intervals["tiny_maximized"] <= m_intervals["big_maximized"] ) {
+                m_intervals["tiny_maximized"] <= m_intervals["big_maximized"] &&
+                /* sigh, sometime we get 2 times in row the same idle ness
+                   so, to prevent the signal emitted, we also chech that the
+                   big_left does not equal the regular interval */
+                m_big_left != m_intervals["big_minimized"] ) {
         // the user was sufficiently idle for a big break
         if ( m_relax_left == 0 && m_pause_left == 0 ) {
             RSIGlobals::instance()->stats()->increaseStat( IDLENESS_CAUSED_SKIP_BIG );
@@ -441,7 +425,11 @@ void RSITimer::timerEvent( QTimerEvent * )
         resetAfterBigBreak();
         emit bigBreakSkipped();
     } else if ( m_useIdleDetection && t == m_intervals["tiny_maximized"] &&
-                m_tiny_left < m_big_left && !m_ignoreIdleForTinyBreaks ) {
+                m_tiny_left < m_big_left && !m_ignoreIdleForTinyBreaks &&
+                /* sigh, sometime we get 2 times in row the same idle ness
+                   so, to prevent the signal emitted, we also chech that the
+                   big_left does not equal the regular interval */
+                m_tiny_left != m_intervals["tiny_minimized"] ) {
         // the user was sufficiently idle for a tiny break
         if ( m_relax_left == 0 && m_pause_left == 0 ) {
             RSIGlobals::instance()->stats()->increaseStat( IDLENESS_CAUSED_SKIP_TINY );
@@ -542,7 +530,12 @@ RSITimerNoIdle::~RSITimerNoIdle() {}
 
 void RSITimerNoIdle::timerEvent( QTimerEvent * )
 {
-    hibernationDetector();
+    // Just spot some long time inactivity...
+    int idle = idleTime();
+    if ( idle == 600 ) {
+        resetAfterBigBreak();
+    } else if ( idle > 600 )
+        return;
 
     // Don't change the tray icon when suspended, or evaluate
     // a possible break.
@@ -576,15 +569,18 @@ void RSITimerNoIdle::timerEvent( QTimerEvent * )
         m_relax_left = 0;
     }
 
-    kDebug() << " pause_left: " << m_pause_left
-    <<  " tiny_left: " << m_tiny_left  << " big_left: "
-    <<  m_big_left << " m_nextbeak: " << m_nextBreak << endl;
+
+    if ( m_explicitDebug ) {
+        kDebug() << " pause_left: " << m_pause_left
+        <<  " tiny_left: " << m_tiny_left  << " big_left: "
+        <<  m_big_left << " m_nextbeak: " << m_nextBreak << endl;
+    }
 
     if ( m_pause_left > 0 ) {
         --m_pause_left;
         if ( m_pause_left == 0 ) {
             // break is over
-            emit minimize( true );
+            emit minimize();
             emit relax( -1, false );
             if ( m_nextBreak == TINY_BREAK ) {
                 resetAfterTinyBreak();
